Release Steps
=============

Version
-------

Bump version in ``teracy.html5boilerplate.__init__``


CHANGELOG.md
------------

- Copy release notes from django-html5-boilerplate project on issues.teracy.org, for example:

https://issues.teracy.org/secure/ReleaseNote.jspa?version=10005&styleName=Text&projectId=10408&Create=Create&atl_token=BD5N-YNBS-EHHQ-478Z%7C7236c331ad79b8f69e01bf7a4537372c32b8d6a1%7Clin

- Note: Only copy the main issues that is worth mentioning and change the format to Markdown instead.
